@@ -1,28 +1,24 @@
 package POE::Component::IRC::Plugin::Logger;
-BEGIN {
-  $POE::Component::IRC::Plugin::Logger::AUTHORITY = 'cpan:HINRIK';
-}
-BEGIN {
-  $POE::Component::IRC::Plugin::Logger::VERSION = '6.52';
-}
-
+our $AUTHORITY = 'cpan:HINRIK';
+$POE::Component::IRC::Plugin::Logger::VERSION = '6.90';
 use strict;
 use warnings FATAL => 'all';
 use Carp;
 use Encode::Guess;
 use Fcntl qw(O_WRONLY O_APPEND O_CREAT);
-use File::Spec::Functions qw(catdir catfile);
+use File::Glob ':glob';
+use File::Spec::Functions qw(catdir catfile rel2abs);
 use IO::Handle;
+use IRC::Utils qw(lc_irc parse_user strip_color strip_formatting decode_irc);
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Plugin::BotTraffic;
-use POE::Component::IRC::Common qw( l_irc parse_user strip_color strip_formatting irc_to_utf8);
 use POSIX qw(strftime);
 
 sub new {
     my ($package) = shift;
     croak "$package requires an even number of arguments" if @_ & 1;
     my %self = @_;
-    
+
     if (!defined $self{Path} && ref $self{Log_sub} ne 'CODE') {
         die "$package requires a Path";
     }
@@ -31,15 +27,15 @@ sub new {
 
 sub PCI_register {
     my ($self, $irc) = @_;
-    
+
     if (!$irc->isa('POE::Component::IRC::State')) {
         die __PACKAGE__ . ' requires PoCo::IRC::State or a subclass thereof';
     }
-    
+
     if ( !grep { $_->isa('POE::Component::IRC::Plugin::BotTraffic') } values %{ $irc->plugin_list() } ) {
         $irc->plugin_add('BotTraffic', POE::Component::IRC::Plugin::BotTraffic->new());
     }
-    
+
     if ($self->{Restricted}) {
         $self->{dir_perm} = oct 700;
         $self->{file_perm} = oct 600;
@@ -50,10 +46,13 @@ sub PCI_register {
 
     }
 
+    $self->{Path} = bsd_glob($self->{Path}) if ref $self->{Log_sub} ne 'CODE';
     if (defined $self->{Path} && ! -d $self->{Path}) {
-        mkdir $self->{Path}, $self->{dir_perm} or die 'Cannot create directory ' . $self->{Path} . ": $!; aborted";
+        mkdir $self->{Path}, $self->{dir_perm}
+            or die 'Cannot create directory ' . $self->{Path} . ": $!; aborted";
+        $self->{Path} = rel2abs($self->{Path});
     }
-    
+
     $self->{irc} = $irc;
     $self->{logging} = { };
     $self->{Private} = 1 if !defined $self->{Private};
@@ -61,7 +60,7 @@ sub PCI_register {
     $self->{DCC} = 1 if !defined $self->{DCC};
     $self->{Format} = $self->default_format() if !defined $self->{Format};
 
-    $irc->plugin_register($self, 'SERVER', qw(001 332 333 chan_mode 
+    $irc->plugin_register($self, 'SERVER', qw(001 332 333 chan_mode
         ctcp_action bot_action bot_msg bot_public bot_notice join kick msg
         nick part public notice quit topic dcc_start dcc_chat dcc_done));
     $irc->plugin_register($self, 'USER', 'dcc_chat');
@@ -80,7 +79,7 @@ sub S_001 {
 
 sub S_332 {
     my ($self, $irc) = splice @_, 0, 2;
-    my $chan  = irc_to_utf8(${ $_[2] }->[0]);
+    my $chan  = decode_irc(${ $_[2] }->[0]);
     my $topic = $self->_normalize(${ $_[2] }->[1]);
 
     # only log this if we were just joining the channel
@@ -91,7 +90,7 @@ sub S_332 {
 sub S_333 {
     my ($self, $irc) = splice @_, 0, 2;
     my ($chan, $user, $time) = @{ ${ $_[2] } };
-    $chan = irc_to_utf8($chan);
+    $chan = decode_irc($chan);
 
     # only log this if we were just joining the channel
     $self->_log_entry($chan, topic_set_by => $chan, $user, $time) if !$irc->channel_list($chan);
@@ -102,7 +101,7 @@ sub S_chan_mode {
     my ($self, $irc) = splice @_, 0, 2;
     pop @_;
     my $nick = parse_user(${ $_[0] });
-    my $chan = irc_to_utf8(${ $_[1] });
+    my $chan = decode_irc(${ $_[1] });
     my $mode = ${ $_[2] };
     my $arg  = defined $_[3] ? ${ $_[3] } : '';
 
@@ -121,7 +120,7 @@ sub S_ctcp_action {
             $self->_log_entry($sender, action => $sender, $msg);
         }
         else {
-            $recipient = irc_to_utf8($recipient);
+            $recipient = decode_irc($recipient);
             $self->_log_entry($recipient, action => $sender, $msg);
         }
     }
@@ -139,7 +138,7 @@ sub S_notice {
             $self->_log_entry($sender, notice => $sender, $msg);
         }
         else {
-            $target = irc_to_utf8($target);
+            $target = decode_irc($target);
             $self->_log_entry($target, notice => $sender, $msg);
         }
     }
@@ -153,7 +152,7 @@ sub S_bot_action {
     my $msg        = $self->_normalize(${ $_[1] });
 
     for my $recipient (@{ $recipients }) {
-        $recipient = irc_to_utf8($recipient);
+        $recipient = decode_irc($recipient);
         $self->_log_entry($recipient, action => $irc->nick_name(), $msg);
     }
     return PCI_EAT_NONE;
@@ -176,7 +175,7 @@ sub S_bot_public {
     my $msg      = $self->_normalize(${ $_[1] });
 
     for my $chan (@{ $channels }) {
-        $chan = irc_to_utf8($chan);
+        $chan = decode_irc($chan);
         $self->_log_entry($chan, privmsg => $irc->nick_name(), $msg);
     }
     return PCI_EAT_NONE;
@@ -188,7 +187,7 @@ sub S_bot_notice {
     my $msg     = $self->_normalize(${ $_[1] });
 
     for my $target (@{ $targets }) {
-        $target = irc_to_utf8($target);
+        $target = decode_irc($target);
         $self->_log_entry($target, notice => $irc->nick_name(), $msg);
     }
     return PCI_EAT_NONE;
@@ -197,7 +196,7 @@ sub S_bot_notice {
 sub S_join {
     my ($self, $irc) = splice @_, 0, 2;
     my ($joiner, $user, $host) = parse_user(${ $_[0] });
-    my $chan = irc_to_utf8(${ $_[1] });
+    my $chan = decode_irc(${ $_[1] });
 
     $self->_log_entry($chan, join => $joiner, "$user\@$host", $chan);
     return PCI_EAT_NONE;
@@ -206,7 +205,7 @@ sub S_join {
 sub S_kick {
     my ($self, $irc) = splice @_, 0, 2;
     my $kicker = parse_user(${ $_[0] });
-    my $chan   = irc_to_utf8(${ $_[1] });
+    my $chan   = decode_irc(${ $_[1] });
     my $victim = ${ $_[2] };
     my $msg    = $self->_normalize(${ $_[3] });
 
@@ -230,7 +229,7 @@ sub S_nick {
     my $channels = ${ $_[2] };
 
     for my $chan (@{ $channels }) {
-        $chan = irc_to_utf8($chan);
+        $chan = decode_irc($chan);
         $self->_log_entry($chan, nick_change => $old_nick, $new_nick);
     }
     return PCI_EAT_NONE;
@@ -239,7 +238,7 @@ sub S_nick {
 sub S_part {
     my ($self, $irc) = splice @_, 0, 2;
     my ($parter, $user, $host) = parse_user(${ $_[0] });
-    my $chan = irc_to_utf8(${ $_[1] });
+    my $chan = decode_irc(${ $_[1] });
     my $msg  = ref $_[2] eq 'SCALAR' ? ${ $_[2] } : '';
     $msg = $self->_normalize($msg);
 
@@ -254,7 +253,7 @@ sub S_public {
     my $msg      = $self->_normalize(${ $_[2] });
 
     for my $chan (@{ $channels }) {
-        $chan = irc_to_utf8($chan);
+        $chan = decode_irc($chan);
         $self->_log_entry($chan, privmsg => $sender, $msg);
     }
     return PCI_EAT_NONE;
@@ -267,7 +266,7 @@ sub S_quit {
     my $channels = ${ $_[2] };
 
     for my $chan (@{ $channels }) {
-        $chan = irc_to_utf8($chan);
+        $chan = decode_irc($chan);
         $self->_log_entry($chan, quit => $quitter, "$user\@$host", $msg);
     }
     return PCI_EAT_NONE;
@@ -276,7 +275,7 @@ sub S_quit {
 sub S_topic {
     my ($self, $irc) = splice @_, 0, 2;
     my $changer   = parse_user(${ $_[0] });
-    my $chan      = irc_to_utf8(${ $_[1] });
+    my $chan      = decode_irc(${ $_[1] });
     my $new_topic = $self->_normalize(${ $_[2] });
 
     $self->_log_entry($chan, topic_change => $changer, $new_topic);
@@ -319,8 +318,8 @@ sub U_dcc_chat {
     my ($dcc) = grep { $_->isa('POE::Component::IRC::Plugin::DCC') } values %{ $irc->plugin_list() };
     my $info = $dcc->dcc_info($$id);
     my $nick = $info->{nick};
-   
-    for my $msg (@lines) { 
+
+    for my $msg (@lines) {
         $msg = $self->_normalize($msg);
         if (my ($action) = $msg =~ /\001ACTION (.*?)\001/) {
             $self->_log_entry("=$nick", action => $me, $action);
@@ -347,7 +346,7 @@ sub S_dcc_done {
 sub _log_entry {
     my ($self, $context, $type, @args) = @_;
     my ($date, $time) = split / /, (strftime '%Y-%m-%d %H:%M:%S ', localtime);
-    $context = l_irc $context, $self->{irc}->isupport('CASEMAPPING');
+    $context = lc_irc $context, $self->{irc}->isupport('CASEMAPPING');
     my $chantypes = join('', @{ $self->{irc}->isupport('CHANTYPES') || ['#', '&']});
 
     if ($context =~ /^[$chantypes]/) {
@@ -371,7 +370,7 @@ sub _log_entry {
 
     # slash is problematic in a filename, replace it with underscore
     $context =~ s!/!_!g;
-    
+
     my $log_file;
     if ($self->{Sort_by_date}) {
         my $log_dir = catdir($self->{Path}, $context);
@@ -384,7 +383,7 @@ sub _log_entry {
     else {
         $log_file = catfile($self->{Path}, "$context.log");
     }
-    
+
     $log_file = $self->_open_log($log_file);
 
     if (!$self->{logging}->{$context}) {
@@ -401,14 +400,14 @@ sub _open_log {
     my ($self, $file_name) = @_;
     sysopen(my $log, $file_name, O_WRONLY|O_APPEND|O_CREAT, $self->{file_perm})
         or die "Couldn't open or create file '$file_name': $!; aborted";
-    binmode($log, ':utf8');
+    binmode($log, ':encoding(utf8)');
     $log->autoflush(1);
     return $log;
 }
 
 sub _normalize {
     my ($self, $line) = @_;
-    $line = irc_to_utf8($line);
+    $line = decode_irc($line);
     $line = strip_color($line) if $self->{Strip_color};
     $line = strip_formatting($line) if $self->{Strip_formatting};
     return $line;
@@ -503,7 +502,7 @@ logs public, private, and DCC chat messages to disk
 
 POE::Component::IRC::Plugin::Logger is a L<POE::Component::IRC|POE::Component::IRC>
 plugin. It logs messages and CTCP ACTIONs to either F<#some_channel.log> or
-F<some_nickname.log> in the supplied path. In the case of DCC chats, a '=' is 
+F<some_nickname.log> in the supplied path. In the case of DCC chats, a '=' is
 prepended to the nickname (like in irssi).
 
 The plugin tries to detect UTF-8 encoding of every message or else falls back
