@@ -1,16 +1,11 @@
 package POE::Component::IRC::Plugin::Proxy;
-BEGIN {
-  $POE::Component::IRC::Plugin::Proxy::AUTHORITY = 'cpan:HINRIK';
-}
-BEGIN {
-  $POE::Component::IRC::Plugin::Proxy::VERSION = '6.52';
-}
-
+our $AUTHORITY = 'cpan:HINRIK';
+$POE::Component::IRC::Plugin::Proxy::VERSION = '6.90';
 use strict;
 use warnings FATAL => 'all';
 use Carp;
-use Socket;
-use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::IRCD 
+use Socket qw(inet_ntoa);
+use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::IRCD
            Filter::Line Filter::Stackable);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 
@@ -107,17 +102,17 @@ sub S_raw {
     my $input = $self->{irc_filter}->get( [$line] )->[0];
 
     return PCI_EAT_NONE if $input->{command} eq 'PING';
-    
+
     for my $wheel_id (keys %{ $self->{wheels} }) {
         $self->_send_to_client($wheel_id, $line);
     }
 
     return PCI_EAT_NONE if $self->{stashed};
-    
+
     if ($input->{command} =~ /^(?:NOTICE|\d{3})$/) {
         push @{ $self->{stash} }, $line;
     }
-    
+
     $self->{stashed} = 1 if $input->{command} =~ /^(?:376|422)$/;
     return PCI_EAT_NONE;
 }
@@ -126,7 +121,7 @@ sub _send_to_client {
     my ($self, $wheel_id, $line) = splice @_, 0, 3;
     return if !defined $self->{wheels}->{ $wheel_id }->{wheel};
     return if !$self->{wheels}->{ $wheel_id }->{reg};
-    
+
     $self->{wheels}->{ $wheel_id }->{wheel}->put($line);
     return;
 }
@@ -153,7 +148,7 @@ sub _start {
             $self->{irc_filter},
         ],
     );
-    
+
     if ($self->{irc}->connected()) {
         $kernel->yield('_spawn_listener');
     }
@@ -170,13 +165,13 @@ sub _spawn_listener {
         FailureEvent => '_listener_failed',
         Reuse        => 'yes',
     );
-    
+
     if (!$self->{listener}) {
         my $irc = $self->{irc};
         $irc->plugin_del($self);
         return;
     }
-    
+
     $self->{irc}->send_event(irc_proxy_up => $self->{listener}->getsockname());
     return;
 }
@@ -206,7 +201,7 @@ sub _listener_accept {
     else {
         $self->{irc}->send_event(irc_proxy_rw_fail => inet_ntoa( $peeradr ) => $peerport);
     }
-    
+
     return;
 }
 
@@ -318,13 +313,13 @@ sub _shutdown {
 
     my $mysockaddr = $self->getsockname();
     delete $self->{listener};
-    
+
     for my $wheel_id ( $self->list_wheels() ) {
         $self->_close_wheel( $wheel_id );
     }
     delete $self->{wheels};
     $irc->send_event(irc_proxy_down => $mysockaddr);
-    
+
     return;
 }
 
@@ -363,8 +358,8 @@ lightweight IRC proxy/bouncer
 
  my $irc = POE::Component::IRC::State->spawn();
 
- POE::Session->create( 
-     package_states => [ 
+ POE::Session->create(
+     package_states => [
          main => [ qw(_start) ],
      ],
      heap => { irc => $irc },
@@ -393,7 +388,7 @@ Spawn a L<POE::Component::IRC::State> session and add in a
 POE::Component::IRC::Plugin::Proxy plugin object, specifying a bindport and a
 password the connecting IRC clients have to use. When the component is
 connected to an IRC network a listening port is opened by the plugin for
-multiple IRC clients to connect. 
+multiple IRC clients to connect.
 
 Neat, huh? >;o)
 
@@ -436,7 +431,7 @@ is passed. In a scalar context returns the time that the client connected in
 unix time. In a list context returns a list consisting of the peer address,
 port, tthe connect time and the lag in seconds for that connection.
 
-=head1 OUTPUT
+=head1 OUTPUT EVENTS
 
 The plugin emits the following L<POE::Component::IRC>
 events:
